==> dde-launchpad_0.4.6.tar.xz: BUILD/translations/dde-launchpad_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="30"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="40"/>
        <source>Pin to Top</source>
        <translation>Rögzítés a tetejére</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="49"/>
        <source>Remove from favorites</source>
        <translation>Eltávolítás a kedvencekből</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="49"/>
        <source>Add to favorites</source>
        <translation>Hozzáadás a kedvencekhez</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="63"/>
        <source>Send to desktop</source>
        <translation>Küldés az asztalra</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="63"/>
        <source>Remove from desktop</source>
        <translation>Eltávolítás az asztalról</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="73"/>
        <source>Remove from dock</source>
        <translation>Eltávolítás a Dokkolóról</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="73"/>
        <source>Send to dock</source>
        <translation>Küldés a Dokkolóra</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="84"/>
        <source>Add to startup</source>
        <translation>Hozzáadás az automatikus indításhoz</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="84"/>
        <source>Remove from startup</source>
        <translation>Eltávolítás az automatikus indításból</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="89"/>
        <source>Use a proxy</source>
        <translation>Proxy használata</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="95"/>
        <source>Disable display scaling</source>
        <translation>Képernyő méretezés letiltása</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="102"/>
        <source>Uninstall</source>
        <translation>Eltávolítás</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">Csevegés</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">Zene</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Videó</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">Grafika</translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="vanished">Játékok</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">Iroda</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Olvasás</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">Fejlesztés</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">Rendszer</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="vanished">Egyéb</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="obsolete">Keresés</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Indító megjelenítése (alapértelmezés szerint rejtve)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>Az indító láthatóságának váltása</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="19"/>
        <source>Internet</source>
        <translation type="unfinished">Internet</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="21"/>
        <source>Chat</source>
        <translation type="unfinished">Csevegés</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="23"/>
        <source>Music</source>
        <translation type="unfinished">Zene</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="25"/>
        <source>Video</source>
        <translation type="unfinished">Videó</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="27"/>
        <source>Graphics</source>
        <translation type="unfinished">Grafika</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="29"/>
        <source>Game</source>
        <translation type="unfinished">Játékok</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="31"/>
        <source>Office</source>
        <translation type="unfinished">Iroda</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="33"/>
        <source>Reading</source>
        <translation type="unfinished">Olvasás</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="35"/>
        <source>Development</source>
        <translation type="unfinished">Fejlesztés</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="37"/>
        <source>System</source>
        <translation type="unfinished">Rendszer</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="39"/>
        <source>Others</source>
        <translation type="unfinished">Egyéb</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="270"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Biztosan el szeretné távolítani a következőt: %1?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="282"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="296"/>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Categories</source>
        <translation type="vanished">Kategóriák</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="103"/>
        <source>Power</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Beállítások</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="361"/>
        <location filename="../qml/WindowedFrame.qml" line="266"/>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="115"/>
        <source>Control Center</source>
        <translation>Vezérlőpult</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="157"/>
        <source>My Favorites</source>
        <translation>Kedvenceim</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="191"/>
        <source>Add your favorite apps here</source>
        <translation>Adja hozzá kedvenc alkalmazásait ide</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="202"/>
        <source>All Apps</source>
        <translation>Minden alkalmazás</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="346"/>
        <location filename="../qml/WindowedFrame.qml" line="230"/>
        <source>No search results</source>
        <translation>Nincs keresési eredmény</translation>
    </message>
</context>
</TS>

==> dde-launchpad_0.6.12.tar.xz: BUILD/translations/dde-launchpad_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>AnalysisView</name>
    <message>
        <source>No search results</source>
        <translation type="obsolete">Nincs keresési eredmény</translation>
    </message>
</context>
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="31"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="41"/>
        <source>Pin to Top</source>
        <translation>Rögzítés a tetejére</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="50"/>
        <source>Remove from favorites</source>
        <translation>Eltávolítás a kedvencekből</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="50"/>
        <source>Add to favorites</source>
        <translation>Hozzáadás a kedvencekhez</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="64"/>
        <source>Send to desktop</source>
        <translation>Küldés az asztalra</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="64"/>
        <source>Remove from desktop</source>
        <translation>Eltávolítás az asztalról</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="74"/>
        <source>Remove from dock</source>
        <translation>Eltávolítás a Dokkolóról</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="74"/>
        <source>Send to dock</source>
        <translation>Küldés a Dokkolóra</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="85"/>
        <source>Add to startup</source>
        <translation>Hozzáadás az automatikus indításhoz</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="85"/>
        <source>Remove from startup</source>
        <translation>Eltávolítás az automatikus indításból</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="92"/>
        <source>Use a proxy</source>
        <translation>Proxy használata</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="100"/>
        <source>Disable display scaling</source>
        <translation>Képernyő méretezés letiltása</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="107"/>
        <source>Uninstall</source>
        <translation>Eltávolítás</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">Csevegés</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">Zene</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Videó</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">Grafika</translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="vanished">Játékok</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">Iroda</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Olvasás</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">Fejlesztés</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">Rendszer</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="vanished">Egyéb</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="26"/>
        <source>Power</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="40"/>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="29"/>
        <source>Frequently Used</source>
        <translation>Gyakran Használt</translation>
    </message>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="29"/>
        <source>All Apps</source>
        <translation>Minden alkalmazás</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="obsolete">Keresés</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Indító megjelenítése (alapértelmezés szerint rejtve)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>Az indító láthatóságának váltása</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="21"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="23"/>
        <source>Chat</source>
        <translation>Csevegés</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="25"/>
        <source>Music</source>
        <translation>Zene</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="27"/>
        <source>Video</source>
        <translation>Videó</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="29"/>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="31"/>
        <source>Game</source>
        <translation>Játékok</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="33"/>
        <source>Office</source>
        <translation>Iroda</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="35"/>
        <source>Reading</source>
        <translation>Olvasás</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="37"/>
        <source>Development</source>
        <translation>Fejlesztés</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="39"/>
        <source>System</source>
        <translation>Rendszer</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="41"/>
        <source>Others</source>
        <translation>Egyéb</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="313"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Biztosan el szeretné távolítani a következőt: %1?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="325"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="339"/>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="27"/>
        <source>Recently Installed</source>
        <translation>Újonnan Telepített</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="26"/>
        <source>All Apps</source>
        <translation>Minden alkalmazás</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="76"/>
        <source>No search results</source>
        <translation>Nincs keresési eredmény</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="39"/>
        <source>Free sorting</source>
        <translation>Szabad rendezés</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="52"/>
        <source>Sort by category</source>
        <translation>Rendezés Kategóriánként</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="64"/>
        <source>Sort by name</source>
        <translation>Rendezés név szerint</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="124"/>
        <source>Computer</source>
        <translation>Számítógép</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="139"/>
        <source>Pictures</source>
        <translation>Képek</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="154"/>
        <source>Documents</source>
        <translation>Dokumentumok</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="169"/>
        <source>Desktop</source>
        <translation>Asztal</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="184"/>
        <source>Control Center</source>
        <translation>Vezérlőpult</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Categories</source>
        <translation type="vanished">Kategóriák</translation>
    </message>
    <message>
        <source>Power</source>
        <translation type="vanished">Kikapcsolás</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Beállítások</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Keresés</translation>
    </message>
    <message>
        <source>Control Center</source>
        <translation type="vanished">Vezérlőpult</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation type="vanished">Kedvenceim</translation>
    </message>
    <message>
        <source>Add your favorite apps here</source>
        <translation type="vanished">Adja hozzá kedvenc alkalmazásait ide</translation>
    </message>
    <message>
        <source>All Apps</source>
        <translation type="vanished">Minden alkalmazás</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation type="vanished">Nincs keresési eredmény</translation>
    </message>
</context>
</TS>
